summaryrefslogtreecommitdiffstats
path: root/korganizer/actionmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/actionmanager.cpp')
-rw-r--r--korganizer/actionmanager.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/actionmanager.cpp b/korganizer/actionmanager.cpp
index cbb4e42f..c8eefde5 100644
--- a/korganizer/actionmanager.cpp
+++ b/korganizer/actionmanager.cpp
@@ -81,9 +81,9 @@
KOWindowList *ActionManager::mWindowList = 0;
ActionManager::ActionManager( KXMLGUIClient *client, CalendarView *widget,
- TQObject *tqparent, KOrg::MainWindow *mainWindow,
+ TQObject *parent, KOrg::MainWindow *mainWindow,
bool isPart )
- : TQObject( tqparent ), KCalendarIface(), mRecent( 0 ),
+ : TQObject( parent ), KCalendarIface(), mRecent( 0 ),
mResourceButtonsAction( 0 ), mResourceViewShowAction( 0 ), mCalendar( 0 ),
mCalendarResources( 0 ), mResourceView( 0 ), mIsClosing( false )
{
@@ -130,7 +130,7 @@ void ActionManager::init()
TQTimer::singleShot( 0, TQT_TQOBJECT(this), TQT_SLOT( showTipOnStart() ) );
}
// Note: We need this ActionManager to be fully constructed, and
// tqparent() to have a valid reference to it before the following
// addWindow is called.
mWindowList->addWindow( mMainWindow );
@@ -130,7 +130,7 @@ void ActionManager::init()
}
// Note: We need this ActionManager to be fully constructed, and
- // tqparent() to have a valid reference to it before the following
+ // parent() to have a valid reference to it before the following
// addWindow is called.
mWindowList->addWindow( mMainWindow );